@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -47,7 +47,6 @@
  *
  */
 
-
 package com.openexchange.admin.console;
 
 import java.util.ArrayList;
@@ -273,6 +272,16 @@ public class CLIParser {
         return remove ? vals.remove(0) : vals.get(0);
     }
 
+    /**
+     * Returns true if the CLIParser contains the specified option; false otherwise
+     * 
+     * @param o The option
+     * @return Returns true if the CLIParser contains the specified option; false otherwise
+     */
+    public boolean hasOption(final CLIOption o) {
+        return values.containsKey(o.longForm());
+    }
+
     /**
      * Gets the parsed values of all occurrences of given option, or an empty collection if the option was not set.
      *
