@@ -178,6 +178,8 @@ public abstract class ContextAbstraction extends UserAbstraction {
 
     protected String contextname = null;
 
+    protected boolean inServer = false;
+
     private ServiceLoader<? extends ContextConsoleCommonInterface> subclasses = null;
 
     @Override
@@ -203,6 +205,11 @@ public abstract class ContextAbstraction extends UserAbstraction {
         }
     }
 
+    protected boolean parseAndSetInServer(final AdminParser parser) {
+        this.inServer = parser.hasOption(inServerOption);
+        return this.inServer;
+    }
+
     protected void parseAndSetContextQuota(final AdminParser parser, final Context ctx) {
         final String contextQuota = (String) parser.getOptionValue(this.contextQuotaOption);
         if (null != contextQuota) {
