@@ -479,7 +479,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
             try {
                 if (tool.checkAndUpdateSchemaIfRequired(ctx)) {
-                    throw new DatabaseUpdateException("Database is locked or is now beeing updated, please try again later");
+                    throw tool.generateDatabaseUpdateException(ctx.getId().intValue());
                 }
             } catch (final StorageException e) {
                 // Context deletion should be a robust process. Therefore not failing if the schema is not up
@@ -1034,7 +1034,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 throw new NoSuchContextException();
             }
             if (tool.checkAndUpdateSchemaIfRequired(ctx)) {
-                throw new DatabaseUpdateException("Database is locked or is now beeing updated, please try again later");
+                throw tool.generateDatabaseUpdateException(ctx.getId().intValue());
             }
             if (!tool.isContextEnabled(ctx)) {
                 throw new OXContextException(OXContextException.CONTEXT_DISABLED);
@@ -1203,9 +1203,9 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         if (viewFactory != null) {
             ConfigView view;
             try {
-                view = viewFactory.getView(admin_user.getId(), ctx.getId());
-                Boolean check = view.get("com.openexchange.imap.initWithSpecialUse", Boolean.class);
-                if (check != null && check) {
+                view = viewFactory.getView(admin_user.getId().intValue(), ctx.getId().intValue());
+                Boolean check = view.opt("com.openexchange.imap.initWithSpecialUse", Boolean.class, true);
+                if (check != null && check.booleanValue()) {
                     ConfigProperty<Boolean> prop = view.property("user", "com.openexchange.mail.specialuse.check", Boolean.class);
                     prop.set(Boolean.TRUE);
                 }
@@ -1667,6 +1667,39 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
     }
 
+    @Override
+    public boolean existsInServer(Context ctx, Credentials credentials) throws RemoteException, InvalidDataException, StorageException, InvalidCredentialsException {
+        final Credentials auth = credentials == null ? new Credentials("", "") : credentials;
+        BasicAuthenticator.createPluginAwareAuthenticator().doAuthentication(auth);
+
+        if (ctx == null) {
+            throw new InvalidDataException("Given context is invalid");
+        }
+
+        // Trigger plugin extensions
+        {
+            final PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
+            if (null != pluginInterfaces) {
+                for (final OXContextPluginInterface oxContextPlugin : pluginInterfaces.getContextPlugins().getServiceList()) {
+                    try {
+                        oxContextPlugin.existsInServer(ctx, auth);
+                    } catch (final PluginException e) {
+                        LOGGER.error("", e);
+                        throw StorageException.wrapForRMI(e);
+                    }
+                }
+            }
+        }
+
+        if (null != ctx.getId()) {
+            return tool.existsContextInServer(ctx);
+        } else if (null != ctx.getName()) {
+            return tool.existsContextNameInServer(ctx.getName());
+        } else {
+            throw new InvalidDataException("neither id or name is set in supplied context object");
+        }
+    }
+
     @Override
     public boolean checkExists(final Context ctx, final Credentials credentials) throws RemoteException, InvalidDataException, StorageException, InvalidCredentialsException {
         return exists(ctx, credentials);
