@@ -115,7 +115,7 @@ public class CreateLdap2SqlTables extends AbstractCreateTableImpl {
        + "filestore_name VARCHAR(32) DEFAULT NULL,"
        + "filestore_login VARCHAR(32) DEFAULT NULL,"
        + "filestore_passwd VARCHAR(32) DEFAULT NULL,"
-       + "quota_max BIGINT(20) DEFAULT NULL,"
+       + "quota_max BIGINT(20) NOT NULL DEFAULT -1,"
        + "PRIMARY KEY (cid, id),"
        + "INDEX `mailIndex` (cid, mail(255)),"
        + "INDEX `guestCreatedByIndex` (cid, guestCreatedBy)"
@@ -146,7 +146,7 @@ public class CreateLdap2SqlTables extends AbstractCreateTableImpl {
        + "filestore_name VARCHAR(32) DEFAULT NULL,"
        + "filestore_login VARCHAR(32) DEFAULT NULL,"
        + "filestore_passwd VARCHAR(32) DEFAULT NULL,"
-       + "quota_max BIGINT(20) DEFAULT NULL,"
+       + "quota_max BIGINT(20) NOT NULL DEFAULT -1,"
        + "PRIMARY KEY (cid, id)"
      + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
 
@@ -206,8 +206,8 @@ public class CreateLdap2SqlTables extends AbstractCreateTableImpl {
         + "cid INT4 UNSIGNED NOT NULL, "
         + "user INT4 UNSIGNED NOT NULL, "
         + "alias VARCHAR(255) NOT NULL, "
-        + "`uuid` BINARY(16) DEFAULT NULL," 
-        + "PRIMARY KEY (`cid`, `user`, `alias`) " 
+        + "`uuid` BINARY(16) DEFAULT NULL,"
+        + "PRIMARY KEY (`cid`, `user`, `alias`) "
       + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
 
     /**
