@@ -55,6 +55,7 @@ import java.net.URI;
 import java.net.URISyntaxException;
 import java.rmi.RemoteException;
 import java.util.Arrays;
+import java.util.List;
 import com.openexchange.admin.rmi.OXUtilInterface;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.Database;
@@ -64,8 +65,10 @@ import com.openexchange.admin.rmi.dataobjects.Server;
 import com.openexchange.admin.rmi.exceptions.EnforceableDataObjectException;
 import com.openexchange.admin.rmi.exceptions.InvalidCredentialsException;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
+import com.openexchange.admin.rmi.exceptions.NoSuchDatabaseException;
 import com.openexchange.admin.rmi.exceptions.NoSuchObjectException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
+import com.openexchange.admin.storage.interfaces.OXToolStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUtilStorageInterface;
 
 /**
@@ -496,6 +499,74 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         return listDatabase("*", credentials);
     }
 
+    @Override
+    public Database[][] checkDatabase(Credentials credentials) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        Credentials auth = credentials == null ? new Credentials("","") : credentials;
+        basicauth.doAuthentication(auth);
+
+        OXToolStorageInterface oxtools = OXToolStorageInterface.getInstance();
+        List<List<Database>> databases = oxtools.listSchemasBeingLockedOrNeedsUpdate();
+
+        Database[] needingUpdate;
+        {
+            List<Database> list = databases.get(0);
+            needingUpdate = new Database[list.size()];
+            int i = 0;
+            for (Database database : list) {
+                needingUpdate[i++] = database;
+            }
+        }
+
+        Database[] currentlyUpdating;
+        {
+            List<Database> list = databases.get(1);
+            currentlyUpdating = new Database[list.size()];
+            int i = 0;
+            for (Database database : list) {
+                currentlyUpdating[i++] = database;
+            }
+        }
+
+        Database[] outdatedUpdating;
+        {
+            List<Database> list = databases.get(2);
+            outdatedUpdating = new Database[list.size()];
+            int i = 0;
+            for (Database database : list) {
+                outdatedUpdating[i++] = database;
+            }
+        }
+
+        return new Database[][] { needingUpdate, currentlyUpdating, outdatedUpdating };
+    }
+
+    @Override
+    public Database[] unblockDatabase(Database db, Credentials credentials) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException, NoSuchDatabaseException {
+        Credentials auth = credentials == null ? new Credentials("","") : credentials;
+        try {
+            doNullCheck(db);
+        } catch (final InvalidDataException e1) {
+            log.error("Invalid data sent by client!", e1);
+            throw e1;
+        }
+
+        basicauth.doAuthentication(auth);
+
+        try {
+            setIdOrGetIDFromNameAndIdObject(null, db);
+        } catch (NoSuchObjectException e) {
+            throw new NoSuchDatabaseException(e);
+        }
+        final Integer id = db.getId();
+        if (!tool.existsDatabase(id)) {
+            throw new NoSuchDatabaseException("No such database with id " + id);
+        }
+
+        OXToolStorageInterface oxtools = OXToolStorageInterface.getInstance();
+        List<Database> unblockedDatabaseSchema = oxtools.unblockDatabaseSchema(db);
+        return unblockedDatabaseSchema.toArray(new Database[unblockedDatabaseSchema.size()]);
+    }
+
     @Override
     public Server[] listServer(final String search_pattern, Credentials credentials) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
         Credentials auth = credentials == null ? new Credentials("","") : credentials;
@@ -607,4 +678,11 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         }
     }
 
+    @Override
+    public Database createSchema(Credentials credentials, Integer optDBId) throws RemoteException, StorageException, InvalidCredentialsException {
+        Credentials auth = credentials == null ? new Credentials("","") : credentials;
+        basicauth.doAuthentication(auth);
+        return oxutil.createSchema(optDBId);
+    }
+
 }
