@@ -59,6 +59,7 @@ import java.util.Properties;
 import com.openexchange.admin.properties.AdminProperties;
 import com.openexchange.admin.services.AdminServiceRegistry;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.java.Streams;
 
 public class PropertyHandler {
 
@@ -361,7 +362,13 @@ public class PropertyHandler {
 
     protected void addpropsfromfile(final String file) throws FileNotFoundException, IOException {
         final Properties configprops  = new Properties();
-        configprops.load( new FileInputStream(file) );
+        FileInputStream in = null;
+        try {
+            in = new FileInputStream(file);
+            configprops.load(in);
+        } finally {
+            Streams.close(in);
+        }
 
         final Enumeration<?> enumi = configprops.propertyNames();
         while ( enumi.hasMoreElements() ) {
@@ -378,7 +385,12 @@ public class PropertyHandler {
 
             if ( param.toLowerCase().endsWith( "_prop" ) ) {
                 final Properties customprops = new Properties();
-                customprops.load( new FileInputStream( value ) );
+                try {
+                    in = new FileInputStream(value);
+                    customprops.load(in);
+                } finally {
+                    Streams.close(in);
+                }
                 final Enumeration<?> enuma = customprops.propertyNames();
                 Hashtable<String, String> custconfig = new Hashtable<String, String>();
                 if ( this.allPropValues.containsKey( param + "_CONFIG" ) ) {
